/************************************************************************/
/*				                        		*/
/*	  DPG1DemoProject 		                                */
/*						                  	*/
/*					                        	*/
/************************************************************************/
/*	Author: Eric Marsh					        */
/*	Copyright 2016, Digilent Inc.					*/
/************************************************************************/
/*      File Description: 			             		*/
/*					                        	*/
/* This file implements a simple demo application that demonstrates     */
/* how to use the DPG1 library.				                */
/*									*/
/*	Functionality:							*/
/*									*/
/* In the setup() function, the application initializes                 */
/* the DPG1 library object.                                             */
/* In the loop() function, the application repeatedly increases and     */
/* decreases the physical value to be reconstructed by the DA converter.*/
/*					                        	*/
/************************************************************************/
/*      Hookup Guide                                                    */
/*      This demo assumes that you wire the SS pin on PmodDPG1          */
/*        to PIN_DSPI0_SS on your microprocessor.                       */
/*      For chipKit uc32, PIN_DSPI0_SS is pin 10.                       */
/*      For chipKit mx3, PIN_DSPI0_SS is pin 32.                        */
/*      For chipKit wf32, PIN_DSPI0_SS is pin 44                        */
/*      For every other chipKit, please look at its reference manual    */
/*        to find what PIN_DSPI0_SS is defined on that board.           */  		
/*                                                             		*/
/*                                                             		*/
/************************************************************************/
/*  Revision History:			        			*/
/*					                        	*/
/*	06/23/2016(EricM): created	       			        */
/************************************************************************/

/* -------------------------------------------------------------------- */
/*				Include File Definitions                */
/* -------------------------------------------------------------------- */
#include <DPG1.h>
#include <DSPI.h>

/* -------------------------------------------------------------------- */
/*				Global Variables		        */
/* -------------------------------------------------------------------- */
DPG1 myDPG1;

// pressure unit types
#define KPA		0
#define ATM		1
#define PSI		2
#define INH20		3
#define CMH20		4
#define MMHG		5

/* -------------------------------------------------------------------- */
/*	               Procedure Definitions	                        */
/* -------------------------------------------------------------------- */
/***	setup
**
**	Parameters:
**		none
**
**	Return Value:
**		none
**
**	Errors:
**		none
**
**	Description:
**		 Performs basic initialization.		
/*** ---------------------------------------------------------- ***/
void setup(){
  
  //initialize SPI to 1 MHz and SPI mode 0
  myDPG1.begin(PAR_ACCESS_SPI0);
  
  //start up the serial monitor
  Serial.begin(9600);
  
  //small delay for fun
  delay(50);
}

/*** ---------------------------------------------------------- ***/
/***	loop
**
**	Parameters:
**		none
**
**	Return Value:
**		none
**
**	Errors:
**		none
**
**	Description:
**		Main program module. Enters the main program loop.
**              This loop will return the difference in pressure between
**              the two nozzles on the PmodDPG1. Note that if you are not
**		applying differential pressure, then there should a readout
** 		close to zero, with a small decimal number difference.
/*** ---------------------------------------------------------- ***/
void loop(){
  
  int rawData;
  double pressureValue;
  
  // read raw data from PmodDPG1 and print it
  rawData = myDPG1.ReadNozzle();
  Serial.print("Raw data: ");Serial.println(rawData);
  
  // convert raw data into units of kPa and print it
  pressureValue = myDPG1.GetPressure(KPA);
  Serial.print("kPa: ");Serial.println(pressureValue);
  
  // convert raw data into units of atm and print it
  pressureValue = myDPG1.GetPressure(ATM);
  Serial.print("atm: ");Serial.println(pressureValue);
  
  // convert raw data into units of and print it
  pressureValue = myDPG1.GetPressure(PSI);
  Serial.print("psi: ");Serial.println(pressureValue);
  
  // convert raw data into units of and print it
  pressureValue = myDPG1.GetPressure(INH20);
  Serial.print("inH20: ");Serial.println(pressureValue);
  
  // convert raw data into units of and print it
  pressureValue = myDPG1.GetPressure(CMH20);
  Serial.print("cmH20: ");Serial.println(pressureValue);
  
  // convert raw data into units of and print it
  pressureValue = myDPG1.GetPressure(MMHG);
  Serial.print("mmHg: ");Serial.println(pressureValue);
  
  // wait a bit
  delay(1000);
  
}